/*
 *                      EBUILDA: cross-platform build system
 *
 * This file is part of Yeppp! library infrastructure and licensed under Simplified BSD License.
 * See LICENSE.txt for the full text of the license.
 *
 */

package info.yeppp.ebuilda;

import info.yeppp.ebuilda.filesystem.AbsoluteDirectoryPath;
import info.yeppp.ebuilda.filesystem.AbsoluteFilePath;
import info.yeppp.ebuilda.generic.CCompiler;
import info.yeppp.ebuilda.generic.Versioned;

import java.util.Collection;

public class ClangCCompiler extends AbstractCCompiler implements Versioned {

	public static ToolInfo verify(AbsoluteFilePath compilerPath) {
		return ClangCppCompiler.verify(compilerPath);
	}

	ClangCCompiler(AbsoluteFilePath compilerPath, ABI abi, Version version, Collection<AbsoluteDirectoryPath> defaultIncludeDirectories, AbsoluteDirectoryPath sysRoot) {
		super(new ClangCppCompiler(compilerPath, abi, version, defaultIncludeDirectories, sysRoot));
	}

	public ClangCCompiler(ClangCCompiler prototype) {
		super(prototype);
	}

	public GccCompatibleCompilerLinker asLinker(Collection<AbsoluteDirectoryPath> defaultGlobalLibraryDirectories) {
		return ((ClangCppCompiler)this.cppCompiler).asLinker(defaultGlobalLibraryDirectories);
	}

	public BuildMessages compile(AbsoluteFilePath source) {
		return this.cppCompiler.compile(source);
	}

	@Override
	public final void addDefaultGlobalIncludeDirectories() {
		this.cppCompiler.addDefaultGlobalIncludeDirectories();
	}

	@Override
	public CCompiler copy() {
		return new ClangCCompiler(this);
	}

	@Override
	public final Version getVersion() {
		return ((ClangCppCompiler)this.cppCompiler).getVersion();
	}

}
