package info.yeppp.ebuilda;

import info.yeppp.ebuilda.filesystem.AbsoluteFilePath;
import info.yeppp.ebuilda.internals.Program;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class GccOutputParser implements Program.EventHandler {

	GccOutputParser(BuildMessages buildMessages, AbsoluteFilePath source, boolean verboseBuild) {
		this.buildMessages = buildMessages;
		this.verboseBuild = verboseBuild;
		this.source = source;
	}

	private final BuildMessages buildMessages;
	private final boolean verboseBuild;
	private final AbsoluteFilePath source;

	private static final Pattern functionErrorPattern = Pattern.compile("(.+): (In function \\'.+\\'):");
	private static final Pattern headerErrorPattern = Pattern.compile("In file included from (.+?):(\\d+):(?:\\d+:)?");

	@Override
	public void onStdOutLineWrite(String line) {
		if (verboseBuild) {
			System.out.println(line);
		}
		throw new Error(String.format("Unknown compiler message %s", line));
	}

	@Override
	public void onStdErrLineWrite(String line) {
		if (verboseBuild) {
			System.err.println(line);
		}
		final Matcher functionErrorMatcher = functionErrorPattern.matcher(line);
		final Matcher headerErrorMatcher = headerErrorPattern.matcher(line);
		if (functionErrorMatcher.matches()) {
			final AbsoluteFilePath file = new AbsoluteFilePath(Machine.getLocal(), functionErrorMatcher.group(1));
			buildMessages.add(new BuildMessage(BuildMessage.Type.Error, file, null, null, functionErrorMatcher.group(2)));
		} else if (headerErrorMatcher.matches()) {
			final AbsoluteFilePath file = new AbsoluteFilePath(Machine.getLocal(), headerErrorMatcher.group(1));
			final int lineNumber = Integer.parseInt(headerErrorMatcher.group(2));
			buildMessages.add(new BuildMessage(BuildMessage.Type.Error, file, lineNumber, null, null));
		} else {
			final BuildMessage lastMessage = buildMessages.getLastBuildMessage();
//				if (lastMessage == null) {
//					throw new Error(String.format("Unknown compiler message %s", line));
//				} else {
//					lastMessage.appendMessage(System.getProperty("line.separator") + line);
//				}
		}
	}

	@Override
	public void onError(String description) {
		if (verboseBuild) {
			System.err.println(description);
		}
		buildMessages.add(new BuildMessage(BuildMessage.Type.Exception, source, null, null, description));
	}

	@Override
	public void onCompletion(Integer status) {
	}

}
