/*
 *                      EBUILDA: cross-platform build system
 *
 * This file is part of Yeppp! library infrastructure and licensed under Simplified BSD License.
 * See LICENSE.txt for the full text of the license.
 *
 */

package info.yeppp.ebuilda;

import info.yeppp.ebuilda.filesystem.AbsoluteDirectoryPath;
import info.yeppp.ebuilda.filesystem.AbsoluteFilePath;
import info.yeppp.ebuilda.generic.CCompiler;
import info.yeppp.ebuilda.generic.Versioned;
import info.yeppp.ebuilda.internals.Program;

import java.util.Collection;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class MicrosoftCCompiler extends AbstractCCompiler implements Versioned {

	private static final Pattern versionPattern = Pattern.compile("icc version (\\d+(?:\\.\\d+)+)\\b.*");

	public static ToolInfo verify(AbsoluteFilePath compilerPath, Collection<AbsoluteDirectoryPath> additionalPathDirectories) {
		return MicrosoftCppCompiler.verify(compilerPath, additionalPathDirectories);
	}

	MicrosoftCCompiler(AbsoluteFilePath compilerPath, ABI abi, Version version, Collection<AbsoluteDirectoryPath> additionalPathDirectories, Collection<AbsoluteDirectoryPath> defaultIncludeDirectories) {
		super(new MicrosoftCppCompiler(compilerPath, abi, version, additionalPathDirectories, defaultIncludeDirectories));
	}

	public MicrosoftCCompiler(MicrosoftCCompiler prototype) {
		super(prototype);
	}

	public BuildMessages compile(AbsoluteFilePath source) {
		return this.cppCompiler.compile(source);
	}

	@Override
	public final void addDefaultGlobalIncludeDirectories() {
		this.cppCompiler.addDefaultGlobalIncludeDirectories();
	}

	@Override
	public CCompiler copy() {
		return new MicrosoftCCompiler(this);
	}

	@Override
	public final Version getVersion() {
		return ((MicrosoftCppCompiler)this.cppCompiler).getVersion();
	}

}
