/*
 *                      EBUILDA: cross-platform build system
 *
 * This file is part of Yeppp! library infrastructure and licensed under Simplified BSD License.
 * See LICENSE.txt for the full text of the license.
 *
 */

package info.yeppp.ebuilda;

public enum OperatingSystem {
	Windows,
	Linux,
	MacOSX,
	NativeClient;

	public final static OperatingSystem detect() {
		final String osName = System.getProperty("os.name");
		if (osName.startsWith("Windows")) {
			return Windows;
		} else if (osName.equals("Linux")) {
			return Linux;
		} else if (osName.equals("Darwin") || osName.equals("Mac OS X")) {
			return MacOSX;
		} else {
			throw new Error(String.format("Unknown os.name value (%s)", osName));
		}
	}


	@Override
	public String toString() {
		switch (this) {
			case MacOSX:
				return "Mac OS X";
			case NativeClient:
				return "Native Client";
			default:
				return super.toString();
		}
	}
}
