package info.yeppp.ebuilda;

import info.yeppp.ebuilda.filesystem.AbsoluteFilePath;

import java.util.Arrays;

public class ToolInfo {
	public ToolInfo(AbsoluteFilePath path, ABI defaultABI, ABI[] supportedABI, Version version) {
		this.path = path;
		this.defaultABI = defaultABI;
		this.supportedABI = supportedABI == null ? null : new ABI[supportedABI.length];
		if (supportedABI != null) {
			System.arraycopy(supportedABI, 0, this.supportedABI, 0, supportedABI.length);
			if (supportedABI.length > 1) {
				Arrays.sort(supportedABI);
			}
		}
		this.version = version;
	}

	public ToolInfo(AbsoluteFilePath path) {
		this.path = path;
		this.defaultABI = null;
		this.supportedABI = null;
		this.version = null;
	}

	public AbsoluteFilePath getPath() {
		return this.path;
	}

	public boolean isValid() {
		return this.version != null;
	}

	public boolean isSupported(ABI abi) {
		if (this.supportedABI == null) {
			return false;
		} else if (this.supportedABI.length == 1) {
			return this.supportedABI[0].equals(abi);
		} else {
			return Arrays.binarySearch(this.supportedABI, abi) >= 0;
		}
	}

	public ABI getDefaultABI() {
		return this.defaultABI;
	}

	public ABI[] getSupportedABI() {
		if (this.supportedABI == null) {
			return null;
		} else {
			final ABI[] supportedABI = new ABI[this.supportedABI.length];
			System.arraycopy(this.supportedABI, 0, supportedABI, 0, this.supportedABI.length);
			return supportedABI;
		}
	}

	public Version getVersion() {
		return this.version;
	}

	final AbsoluteFilePath path;
	final ABI defaultABI;
	final ABI[] supportedABI;
	final Version version;
}
