package info.yeppp.ebuilda.filesystem;

import info.yeppp.ebuilda.OperatingSystem;

import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.regex.Pattern;

public class FileName {

	public FileName(String filename) {
		if (filename == null) {
			throw new NullPointerException("The filename string is null");
		}
		if (filename.isEmpty()) {
			throw new PathFormatException("The filename string is empty");
		}
		/* Check for forbidden symbols on Windows
		 * Information about forbidden symbols from
		 * http://msdn.microsoft.com/en-us/library/windows/desktop/aa365247.aspx
		 */
		AbsoluteFilePath.checkForForbiddenWindowsPathSymbol(filename, '<');
		AbsoluteFilePath.checkForForbiddenWindowsPathSymbol(filename, '>');
		AbsoluteFilePath.checkForForbiddenWindowsPathSymbol(filename, ':');
		AbsoluteFilePath.checkForForbiddenWindowsPathSymbol(filename, '"');
		AbsoluteFilePath.checkForForbiddenWindowsPathSymbol(filename, '|');
		AbsoluteFilePath.checkForForbiddenWindowsPathSymbol(filename, '?');
		AbsoluteFilePath.checkForForbiddenWindowsPathSymbol(filename, '*');
		AbsoluteFilePath.checkForForbiddenWindowsPathSymbol(filename, '\\');
		AbsoluteFilePath.checkForForbiddenUnixPathSymbol(filename, '/');
		/* Verify the filename */
		AbsoluteFilePath.checkForForbiddenWindowsFileName(filename);
		if (filename.endsWith(".")) {
			throw new PathFormatException(String.format("The file path %s ends with a dot which is not recommended on Unix", filename));
		}
		this.filename = filename;
	}

	public FileName removeExtension(boolean greedy) {
		final int extensionPosition = greedy ? this.filename.indexOf('.') : this.filename.lastIndexOf('.');
		/* No extension or starts with a dot (e.g. .bashrc) */
		if (extensionPosition <= 0) {
			return this;
		} else {
			return new FileName(this.filename.substring(0, extensionPosition));
		}
	}

	public FileName removeExtension(String extension) {
		if (!extension.startsWith(".")) {
			extension = "." + extension;
		}
		if (this.filename.endsWith(extension)) {
			return new FileName(this.filename.substring(0, this.filename.length() - extension.length()));
		} else {
			return this;
		}
	}

	public FileName addExtension(String extension) {
		if (!extension.startsWith(".")) {
			extension = "." + extension;
		}
		return new FileName(this.filename + extension);
	}

	@Override
	public boolean equals(Object obj) {
		if (obj instanceof FileName) {
			return this.filename.equals(((FileName) obj).filename);
		} else if (obj instanceof String) {
			return this.filename.equals((String) obj);
		} else {
			return false;
		}
	}

	@Override
	public String toString() {
		return this.filename;
	}

	final String filename;
}
