/*
 *                      EBUILDA: cross-platform build system
 *
 * This file is part of Yeppp! library infrastructure and licensed under Simplified BSD License.
 * See LICENSE.txt for the full text of the license.
 *
 */

package info.yeppp.ebuilda.generic;

import info.yeppp.ebuilda.ABI;
import info.yeppp.ebuilda.BuildMessages;
import info.yeppp.ebuilda.filesystem.AbsoluteDirectoryPath;
import info.yeppp.ebuilda.filesystem.AbsoluteFilePath;

public interface Assembler {

	public BuildMessages assemble(AbsoluteFilePath sourcePath);

	public AbsoluteFilePath getObjectPath(AbsoluteFilePath sourcePath);

	public void setSourceDirectory(AbsoluteDirectoryPath sourceDirectory);

	public AbsoluteDirectoryPath getSourceDirectory();

	public void setObjectDirectory(AbsoluteDirectoryPath objectDirectory);

	public AbsoluteDirectoryPath getObjectDirectory();

	public void setVerboseBuild(boolean verboseBuild);

	public boolean isVerboseBuild();

	public void setDebugInformation(boolean debugInformation);

	public boolean getDebugInformation();

	public boolean addIncludeDirectory(AbsoluteDirectoryPath includePath);

	public boolean removeIncludeDirectory(AbsoluteDirectoryPath includePath);

	public void clearIncludeDirectories();

	public boolean addMacro(String name);

	public boolean addMacro(String name, String value);

	public boolean removeMacro(String name);

	public void clearMacros();

	public void clearAll();

	public ABI getABI();

	public Assembler copy();

}
