/*
 *                      EBUILDA: cross-platform build system
 *
 * This file is part of Yeppp! library infrastructure and licensed under Simplified BSD License.
 * See LICENSE.txt for the full text of the license.
 *
 */

package info.yeppp.ebuilda.generic;

import info.yeppp.ebuilda.ABI;
import info.yeppp.ebuilda.BuildMessages;
import info.yeppp.ebuilda.PositionIndependentCodeGeneration;
import info.yeppp.ebuilda.filesystem.AbsoluteDirectoryPath;
import info.yeppp.ebuilda.filesystem.AbsoluteFilePath;

import java.util.Collection;

public interface Linker {

	public BuildMessages linkExecutable(AbsoluteFilePath executablePath, Collection<AbsoluteFilePath> objectPaths);

	public BuildMessages linkDynamicLibrary(AbsoluteFilePath libraryPath, Collection<AbsoluteFilePath> objectPaths);

	public void setDebugInformation(boolean debugEnabled);

	public boolean getDebugInformation();

	public void setBinariesDirectory(AbsoluteDirectoryPath binariesDirectory);

	public AbsoluteDirectoryPath getBinariesDirectory();

	public void setObjectDirectory(AbsoluteDirectoryPath objectDirectory);

	public AbsoluteDirectoryPath getObjectDirectory();

	public void setVerboseBuild(boolean verboseBuild);

	public boolean isVerboseBuild();

	public void setGlobalOptimization(boolean globalOptimization);

	public boolean getGlobalOptimization();

	public boolean addStaticLibraryDependence(String libraryName);

	public boolean removeStaticLibraryDependence(String libraryName);

	public void clearStaticLibraryDependences();

    public boolean addDynamicLibraryDependence(String libraryName);
    
    public boolean removeDynamicLibraryDependence(String libraryName);

    public void clearDynamicLibraryDependences();

	public void setRuntimeLibraryUse(boolean runtimeLibraryUse);

	public boolean getRuntimeLibraryUse();

	public void addDefaultGlobalLibraryDirectories();

	public boolean addGlobalLibraryDirectory(AbsoluteDirectoryPath libraryDirectory);

	public void addGlobalLibraryDirectories(Collection<AbsoluteDirectoryPath> libraryDirectories);

	public boolean removeGlobalLibraryDirectory(AbsoluteDirectoryPath libraryDirectory);

	public void clearGlobalLibraryDirectories();

	public PositionIndependentCodeGeneration getPIC();

	public void setPIC(PositionIndependentCodeGeneration pic);

	public boolean addLibraryDirectory(AbsoluteDirectoryPath libraryDirectory);

	public void addLibraryDirectories(Collection<AbsoluteDirectoryPath> libraryDirectory);

	public boolean removeLibraryDirectory(AbsoluteDirectoryPath libraryDirectory);

	public void clearLibraryDirectories();

	public void clearAll();

	public ABI getABI();

	public Linker copy();

}
